[O] BUG - Problem in tangle-mode

2013-06-11 Thread Rainer M Krug

Eric Schulte schulte.e...@gmail.com writes:


 I've added a :tangle-mode header argument which may be used to control
 the permissions of tangled files.  See the manual for instructions on
 it's usage.


 Thanks a lot. I will try it out today or tomorrow.

 I did, and there is a problem with tangling multiple blocks into a
 single file:


 Oh, stupid of me.  Thanks for sending this alert, I've just pushed up a
 change which should fix this problem.  We now wait to set the file modes
 until after all blocks are tangled and after the post-tangle-hook has
 been run.

 Thanks,

Hi

Unfortunately, it is now worse, as even without the tangle-mode header,
I can't tangle two blocks - the second block overwrites the before
tangled blocks. It tells me that two blocks were tangled, but only the
last one is in the tangled file.

I will for revert for now to the version from yesterday.

Cheers,

Rainer

-- 
Rainer M. Krug

email: RMKrugatgmaildotcom


pgpyXPR_RfcTt.pgp
Description: PGP signature


[O] Issue with HTML export of Org document with a list

2013-06-11 Thread Vladimir Lomov
Hello,
I faced a strange problem with either my configuration or Org settings.

Please consider the attached Org document, ~ex.org~ and it's export to
HTML.

What I expect (and that used to be earlier): a list with sequential
numbers each has source block.

Would be glad to provide more information.

Thanks in advance.

---
WBR, Vladimir Lomov

-- 
Okay ... I'm going home to write the I HATE RUBIK's CUBE HANDBOOK FOR
DEAD CAT LOVERS ...


ex.org
Description: Lotus Organizer
Title: Example document






Example document

Hello, I faced with a problem when export Org document with a list and
block examples within to HTML.


Let's consider following small initialization file for Emacs

#+BEGIN_SRC emacs-lisp :tangle min-org.el :padline no




(add-to-list 'load-path "/usr/share/emacs/site-lisp/org")
(require 'org)
(require 'ox-html)


#+END_SRC
List is written according to guide for lists in manual,
which says that all items belong to one list must be indented on
the same level. Interestingly enough, that even M-q works wrong
on this example: it puts beginning of first sentence after block
on the same line as END_SRC.


The Emacs is started by following command in terminal

#+BEGIN_SRC sh




emacs -Q -l min-org.el


#+END_SRC
Here min-org.el file is the one tangled from previous source block.


To demonstrate the problem it is enough to export to HTML this
document and to see the result. For example, let's take a look on
this source block




(add-to-list 'load-path "/usr/share/emacs/site-lisp/org")
(require 'org)
(require 'ox-html)
(add-to-list 'load-path "~/.emacs.d/mode")



I have cdlatex.el file in ~/.emacs.d/mode.


While one have to indent BEGIN|END of source block as it is
requirement for lists, it is unnecessary to indent they content.
Moreover it would be wrong because tangled code will be indented
too and it is may be undesired. Let's see another example of source
block




(add-to-list 'load-path "/usr/share/emacs/site-lisp/org")
(require 'org)
(require 'ox-html)
(add-to-list 'load-path "/usr/share/emacs/site-lisp/auctex")
(add-to-list 'load-path "~/.emacs.d/mode")



But something is fundamentally broken, either on my side or with
Org settings.


Because every item with a source block which content is not
indented (as it should be) will break the list and any following
item (considered as sequential item in one list) will be
interpreted as new list. To finish with list let's show once
again minimal example of Emacs initialization for Org mode with
cdlatex

#+BEGIN_SRC emacs-lisp :tangle min-org-cdlatex.el :noweb yes :padline no





(add-to-list 'load-path "usr/share/emacs/site-lisp/auctex")
   (add-to-list 'load-path "~.emacs.d/mode")


#+END_SRC
Is this the last sentence of last item of the one list of the document?



However, lists without source blocks works fine


First. First. First. First. First. First. First. First. First.
First. First. First. First. First. First. First. First. First.
First. First. First. First. First. First. First. First. First.
First. First. First. First. First.

Second, Second, Second, Second, Second, Second, Second, Second,
Second, Second, Second, Second, Second, Second, Second, Second,

Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third. Third.




Another problem (?). First and third entries of above list isn't
reformatted by M-q.




Org-mode version 8.0.3 (release_8.0.3-225-g8e9c10 @ usr/share/emacs/site-lisp/org)




Author: Vladimir Lomov
Created: 2013-06-11 Вт 16:41
Emacs 24.3.50.1 (Org mode 8.0.3)
Validate





Re: [O] Org-mode and Taskjuggler

2013-06-11 Thread Christian Egli
Hi Louis

Louis Turk l...@dayspringpublisher.com writes:

 I'm very interested in your work to get Org-mode to export to
 Taskjuggler version 3 --- very exciting! Being able to export to tj3
 from org-mode would be extremely helpful to me. 

Cool.

 However, I'm having trouble getting it to work. I suspect that the
 documentation I've been reading is too old --- for version 2 of
 Taskjuggler---, and I have version 3 installed.

Yes, the documentation should be updated. John Hendy promised to do so a
while ago :-) (hint, hint).

What are the problems you are encountering? It should work out of the
box. Once you have an org file as explained on the worg page you just
invoke the exporter with C-c C-e J o for example and you should see the
schedule in a browser.

 Would you please send me:

 1 The related code in your .emacs file. 

There is nothing special in my .emacs file. You need to include contrib
to your load path (add-to-list 'load-path ~/src/org-mode/contrib/lisp)
and you need to enable the taskjuggler exporter (M-x customize
org-export-backends).

 2 A sample full-featured org-mode file that compiles successfully to
   tj3. 

The one on from the taskjuggler tutorial on the worg page should work.

 3 Any up-to-date documentation that is available.

The best ATM is the tutorial on worg and the comments in the code.

 4 Anything other information needed to get it to work.

If there is any other info needed then I'd say it is the official
TaskJuggler documentation.

 Thank you in advance for your help. And thanks for all your work
 already done on this project.

My pleasure.

HTH
Christian

-- 
Christian Egli
Swiss Library for the Blind, Visually Impaired and Print Disabled
Grubenstrasse 12, CH-8045 Zürich, Switzerland

-
Tag der offenen Tuer
Die SBS laedt Sie herzlich ein: 29. Juni 2013 von 9 bis 16 Uhr.
Mehr Informationen erhalten Sie unter http://www.sbs.ch/offenetuer



[O] empty LaTeX export template

2013-06-11 Thread Andreas Leha
Hi all,

I am lazy (main reason for this question) and I would like to avoid
filling my org-latex-classes with too many entries (surrogate reason).

So I'd like to ask: Is there a possibility to get a really empty LaTeX
export that reads everything (including the documentclass) from the
#+LATEX_HEADER ?

The reason for this is, that many journals/conferences come with their
own LaTeX template (if I am lucky, that is).  It would be very
convenient, if I could just yank the provided header into my *.org
file (and prefix with #+LATEX_HEADER).

Is that possible?

Regards,
Andreas




Re: [O] export to odt

2013-06-11 Thread Eric S Fraga
Manfred Lotz manfred.l...@arcor.de writes:

[...]

 The following worked fine: I loaded the exported odt document, changed
 the Heading 1 style to do a page break before the heading and saved the
 template as my.ott (I copied it into the ~/org directory).

Thanks.  Very helpful.

I have two different questions about exporting to ODT, one related to
style and other not:

1. Description lists are indented somehow, both the item and the
 description.  I would like to change the indentation but the
 LibreOffice sytle dialogue doesn't show any indentation.  I cannot
 find where the indentation is specified.

2. The title and author fields in the exported document are protected in
 some way and I cannot figure out how to enable editing on them.  I
 can change the style for these just fine but I cannot change the
 text.

Can you please point me in the right direction for either or both of
these?  I am a n00b when it comes LibreOffice etc. unfortunately.

Thanks,
eric
-- 
: Eric S Fraga (0xFFFCF67D), Emacs 24.3.50.1, Org release_8.0.3-193-g334581




Re: [O] bug in new exporter

2013-06-11 Thread Nicolas Goaziou
Hello,

Nick Dokos ndo...@gmail.com writes:

 Nicolas Goaziou n.goaz...@gmail.com writes:

 With 

#+ATTR_LATEX:  :options scale=1.5:width  :placement [htb!]
 it fails here
(attr (org-export-read-attribute :attr_latex parent))
  
 which evalues to something like

 Result: (:options scale=1.5 :placement [htb!] :width )

 when it doesn't crash.

 This bug should be fixed in maint. Thanks to both of you for identifying
 it.


 And also in master, correct? I can never remember who goes first.

Correct.

Basically, if current version is a.b.c, a change in maint will appear
in a.b.c+1 whereas a change in master will appear in a.b+1.

 Just a heads-up: As part of testing this, I stumbled on an unrelated
 current-working-directory problem, where on exporting to pdf, the
 pdflatex of the produced tex file fails to find an image file
 specified with a relative pathname (it works fine with an absolute
 path name). The tex file looks OK and I can process it from the
 command line. I'll try to pin this down more precisely,

Problem probably comes from `org-latex-compile'.

 but do I understand correctly that the processing of the tex file
 should take place with the current working directory set to the
 directory of the org file?

Yes.


Regards,

-- 
Nicolas Goaziou



Re: [O] bug in new exporter

2013-06-11 Thread Nicolas Goaziou
Nick Dokos ndo...@gmail.com writes:

 Nick Dokos ndo...@gmail.com writes:

 Just a heads-up: As part of testing this, I stumbled on an unrelated
 current-working-directory problem, where on exporting to pdf, the
 pdflatex of the produced tex file fails to find an image file specified
 with a relative pathname (it works fine with an absolute path name). The
 tex file looks OK and I can process it from the command line. I'll try
 to pin this down more precisely, but do I understand correctly that the
 processing of the tex file should take place with the current working
 directory set to the directory of the org file?


 The problem was that I had customized my org-latex-pdf-process to the
 texi2dvi recommended value:

  texi2dvi -p -b -c -V %f

 The -c (equivalently: --clean or --build=clean) breaks relative paths
 because texi2dvi executes in a different directory. The *Org PDF LaTeX
 Output* buffer shows

   /usr/bin/texi2dvi: cd /home/nick/src/org/latex/foo.t2d/pdf/build

 whereas the org file was in /home/nick/src/org/latex.

 If you use texi2dvi, beware of -c (and also --tidy I presume).

 So nothing to do with org, but maybe the customization option should not
 include the -c.

I also use texi2dvi, but I don't have any compilation problem with
images, even with a relative path.

Would you mind providing an ECM for that?


Regards,

-- 
Nicolas Goaziou



Re: [O] Org-mode latex pdf export issue: Underlined lines not breaking properly

2013-06-11 Thread Nicolas Goaziou
Hello,

Feng Shu tuma...@gmail.com writes:

 When the article is writen with Chinese,  soul will output:

 #+begin_src
 soul Error: Reconstruction failed.
 #+end_src

 and underline word will dispear from  the output pdf file!

 A tmp solution is :


 \ul{\mbox{中文测试}}

 but,when it can't break lines properly too.

  1. Does \underline{中文测试} work properly (notwithstanding the line
 breaks)?
  2. Does \uline from ulem package handle it correctly, including the
 line breaks?


Regards,

-- 
Nicolas Goaziou



Re: [O] empty LaTeX export template

2013-06-11 Thread Suvayu Ali
On Tue, Jun 11, 2013 at 11:31:39AM +0200, Andreas Leha wrote:
 
 So I'd like to ask: Is there a possibility to get a really empty LaTeX
 export that reads everything (including the documentclass) from the
 #+LATEX_HEADER ?
 
 The reason for this is, that many journals/conferences come with their
 own LaTeX template (if I am lucky, that is).  It would be very
 convenient, if I could just yank the provided header into my *.org
 file (and prefix with #+LATEX_HEADER).

I think you can just define a minimal class in org-latex-classes;
something like

  \documentclass{article}
  [NO-DEFAULT-PACKAGES]
  [NO-PACKAGES]
  [EXTRA]

Then none of the packages listed in org-latex-default-packages-alist and
org-latex-packages-alist are included, and only the
#+LATEX_HEADER(_EXTRA) keywords are considered.

Hope this helps,

-- 
Suvayu

Open source is the future. It sets us free.



Re: [O] Org-mode latex pdf export issue: Underlined lines not breaking properly

2013-06-11 Thread Feng Shu
Nicolas Goaziou n.goaz...@gmail.com writes:

 Hello,

 Feng Shu tuma...@gmail.com writes:

 When the article is writen with Chinese,  soul will output:

 #+begin_src
 soul Error: Reconstruction failed.
 #+end_src

 and underline word will dispear from  the output pdf file!

 A tmp solution is :


 \ul{\mbox{中文测试}}

 but,when it can't break lines properly too.

   1. Does \underline{中文测试} work properly (notwithstanding the line
  breaks)?

\underline can show chinese, but the command can't resolve lines
breaking properly.

   2. Does \uline from ulem package handle it correctly, including the
  line breaks?

\uline seem to work properly.




 Regards,

-- 



Re: [O] empty LaTeX export template

2013-06-11 Thread Andreas Leha
Suvayu Ali fatkasuvayu+li...@gmail.com writes:

 On Tue, Jun 11, 2013 at 11:31:39AM +0200, Andreas Leha wrote:
 
 So I'd like to ask: Is there a possibility to get a really empty LaTeX
 export that reads everything (including the documentclass) from the
 #+LATEX_HEADER ?
 
 The reason for this is, that many journals/conferences come with their
 own LaTeX template (if I am lucky, that is).  It would be very
 convenient, if I could just yank the provided header into my *.org
 file (and prefix with #+LATEX_HEADER).

 I think you can just define a minimal class in org-latex-classes;
 something like

   \documentclass{article}
   [NO-DEFAULT-PACKAGES]
   [NO-PACKAGES]
   [EXTRA]

 Then none of the packages listed in org-latex-default-packages-alist and
 org-latex-packages-alist are included, and only the
 #+LATEX_HEADER(_EXTRA) keywords are considered.

 Hope this helps,

Hi Suvayu,

this did help, indeed.  Thanks a lot.  I did not think it was that easy.

I found, that I can just omit the documentclass from the
org-latex-classes.

So, now I have:
--8---cut here---start-8---
(add-to-list 'org-latex-classes
 '(bare
   
\[NO-DEFAULT-PACKAGES]
\[NO-PACKAGES]
\[EXTRA]
   (\\section{%s} . \\section*{%s})
   (\\subsection{%s} . \\subsection*{%s})
   (\\subsubsection{%s} . \\subsubsection*{%s})))
--8---cut here---end---8---

This should work in most cases.

To use this I do:
--8---cut here---start-8---
#+OPTIONS: toc:nil author:nil skip:nil
#+LATEX_CLASS: bare
#+LATEX_HEADER: % everything from the template
--8---cut here---end---8---


One problem remains, though:  orgmode keeps messing with the title.

I can, of course, set the title through #+TITLE: but I would prefer to
set it through some #+LATEX_HEADER as the templates often require their
own title setting directives.

So, my follow-up question is:  How can I get orgmode to not fiddle with
the title in a LaTeX export?

Regards,
Andreas




Re: [O] Org-mode latex pdf export issue: Underlined lines not breaking properly

2013-06-11 Thread Nicolas Goaziou
Feng Shu tuma...@gmail.com writes:

 Nicolas Goaziou n.goaz...@gmail.com writes:
   1. Does \underline{中文测试} work properly (notwithstanding the line
  breaks)?

 \underline can show chinese, but the command can't resolve lines
 breaking properly.

   2. Does \uline from ulem package handle it correctly, including the
  line breaks?

 \uline seem to work properly.

Then, the best solution seems to add ulem package to
`org-latex-default-packages-alist' and use \ulem for underline. soul
will only be used for strike-through.

Is there any objection to this change?


Regards,

-- 
Nicolas Goaziou



Re: [O] BUG in org-element-context

2013-06-11 Thread Nicolas Goaziou
Hello,

Eric Schulte schulte.e...@gmail.com writes:

 To demonstrate, run M-: (org-element-context) with the point at the
 beginning of the following, and notice that the second ) is not
 included in the returned string.

   call_foo(bar=(+ 2 2))

Thanks for the report.

Parser uses `org-babel-inline-lob-one-liner-regexp', which is unable to
match this correctly. What do you suggest to use instead?


Regards,

-- 
Nicolas Goaziou



Re: [O] Org-mode latex pdf export issue: Underlined lines not breaking properly

2013-06-11 Thread Feng Shu
Nicolas Goaziou n.goaz...@gmail.com writes:

 Feng Shu tuma...@gmail.com writes:

 Nicolas Goaziou n.goaz...@gmail.com writes:
   1. Does \underline{中文测试} work properly (notwithstanding the line
  breaks)?

 \underline can show chinese, but the command can't resolve lines
 breaking properly.

   2. Does \uline from ulem package handle it correctly, including the
  line breaks?

 \uline seem to work properly.

 Then, the best solution seems to add ulem package to
 `org-latex-default-packages-alist' and use \ulem for underline. soul
 will only be used for strike-through.

 Is there any objection to this change?

May be \ulem should be used for strike-through too! 



 Regards,

-- 



Re: [O] A simple way to search only headlines

2013-06-11 Thread Thorsten Jolitz
Suvayu Ali fatkasuvayu+li...@gmail.com writes:

 I wonder if semantic search can be leveraged to achieve the same.  It
 might open other possibilities: searching only links, list items, source
 blocks, ...  I think you get the point.  :-p

navi-mode.el works for Org-mode buffers too, e.g. using 

,-
| worg/org-contrib/babel/intro.org
`-

as an sufficiently complex example file, the following simple
keybindings yield the following search results in the *Navi* buffer:

command (show headlines up to level 2):
,--
| 2
`--

result:
,--
| 28 matches for ^\*\*?  in buffer: intro.org
|  14:* Improving this document  :noexport:
|  15:** DONE Document slice indexing of tables
|  16:** DONE Document synonymous alternatives
|  18:** DONE Describe useful functions
|  22:** DONE Language support
|  27:** DONE Document noweb references
|  29:** TODO Developments
|  55:** DONE Useful variables
|  57:** TODO Language specific header arguments
| 127:** DONE What function is bound to C-c '?
| 129:* Introduction
| 153:* Overview
| 179:* Initial Configuration
| 203:* Code Blocks
| 208:** Code Blocks in Org
| 241:** Code Blocks in Babel
| 268:* Source Code Execution
| 360:** Capturing the Results of Code Evaluation
| 429:** Session-based Evaluation
| 453:** Arguments to Code Blocks
| 539:** In-line Code Blocks
| 546:** Code Block Body Expansion
| 593:** A Meta-programming Language for Org-mode
| 652:* Using Code Blocks in Org Tables
| 842:* The Library of Babel
| 886:* Literate Programming
|1098:* Reproducible Research
|1136:* Footnotes
`--

command (show source-code blocks):
,--
| b
`--

result:

,---
| 30 matches for [long regexp] in buffer:intro.org
| 
|  93:#+begin_src python :file outfile.txt
| 225:#+begin_src org
| 234:#+begin_src org
| 249:#+begin_src org
| 289:#+begin_src ruby
| 304:#+begin_src sh
| 322:#+begin_src R :colnames yes
| 346:#+begin_src ditaa :file blue.png :cmdline -r
| 385:#+begin_src python :results value
| 414:#+begin_src python :results output
| 469:#+begin_src python
| 512:#+begin_src emacs-lisp
| 579:#+begin_src emacs-lisp :rownames yes :var data=user-data
| 585:#+begin_src emacs-lisp
| 647:#+begin_src R :session R-pie-example :file ../../images/babel/dirs.png
| 696:#+begin_src R 
| 776:#+begin_src emacs-lisp
| 788:#+begin_src sh :results silent
| 800:#+begin_src sh :results silent
| 812:#+begin_src ruby :results silent
| 824:#+begin_src python :results silent
| 837:#+begin_src R :results silent
| 878:  #+begin_src emacs-lisp 
| 950:#+begin_src sh :exports none
| 962:#+begin_src sh :exports none
| 983:#+begin_src sh :tangle hello.sh :exports none :noweb yes
| 994:#+begin_src sh 
|1051:   #+begin_src sh 
|1056:   #+begin_src sh
|1065:   #+begin_src emacs-lisp 
`---

command (show headlines up to level 2 and source-code blocks):

,--
| C-2 b
`--

result:

,---
| 58 matches for [long regexp] in buffer:intro.org
| 
|  14:* Improving this document  :noexport:
|  15:** DONE Document slice indexing of tables
|  16:** DONE Document synonymous alternatives
|  18:** DONE Describe useful functions
|  22:** DONE Language support
|  27:** DONE Document noweb references
|  29:** TODO Developments
|  55:** DONE Useful variables
|  57:** TODO Language specific header arguments
|  93:#+begin_src python :file outfile.txt
| 127:** DONE What function is bound to C-c '?
| 129:* Introduction
| 153:* Overview
| 179:* Initial Configuration
| 203:* Code Blocks
| 208:** Code Blocks in Org
| 225:#+begin_src org
| 234:#+begin_src org
| 241:** Code Blocks in Babel
| 249:#+begin_src org
| 268:* Source Code Execution
| 289:#+begin_src ruby
| 304:#+begin_src sh
| 322:#+begin_src R :colnames yes
| 346:#+begin_src ditaa :file blue.png :cmdline -r
| 360:** Capturing the Results of Code Evaluation
| 385:#+begin_src python :results value
| 414:#+begin_src python :results output
| 429:** Session-based Evaluation
| 453:** Arguments to Code Blocks
| 469:#+begin_src python
| 512:#+begin_src emacs-lisp
| 539:** In-line Code Blocks
| 546:** Code Block Body Expansion
| 579:#+begin_src emacs-lisp :rownames yes :var data=user-data
| 585:#+begin_src emacs-lisp
| 593:** A Meta-programming Language for Org-mode
| 647:#+begin_src 

Re: [O] how to disable timestamp html export

2013-06-11 Thread OSiUX
El mié, 05 jun 2013, Nick Dokos decía:

 OSiUX xu...@osiux.com.ar writes:
 
  When export using org-publish-project,
  Org add a comment with timestamp in HTML:
 
   # git diff
 
   html xmlns=http://www.w3.org/1999/xhtml; lang=es xml:lang=es
head
titleviewing two years of orgmode with gnuplot/title
   -!-- 2013-06-05 mié 12:10 --
   +!-- 2013-06-05 mié 12:38 --
meta  http-equiv=Content-Type content=text/html;charset=utf-8 /
meta  name=generator content=Org-mode /
 
  In my .emacs, I have:
 
  (setq org-publish-project-alist
(quote ((osiux-blog-org
  ...others...options...
  :with-timestamps nil
 
  How I can disable this feature?
 
 
 To do it globally, customize org-export-time-stamp-file and set it to
 nil.
 
 Per file, you can use an option:
 
 --8---cut here---start-8---
 #+OPTIONS: timestamp:nil
 --8---cut here---end---8---
 
 or through a local variable by adding this at the *end* of the file:
 
 --8---cut here---start-8---
 # Local Variables:
 # org-export-time-stamp-file: nil
 # End:
 --8---cut here---end---8---
 
 You will need to close and reopen the file in this case, for it
 to take effect.
 
 OTOH, it's just a comment: org is trying to be helpful and tell you
 when the html file was produced. Why do you want to get rid of it?
 At some point, it might save you hours of debugging (ok, rhetorical
 exaggeration perhaps, but still...)

Nic, currently Orgmode is regenerating all .html
files, not just modified (.org), maybe that's
the error?

I use git as version control for html files
because it facilitates the deploy of my blog and
was going to be detected modified files when in
fact they were exactly the same except for the
timestamp.

Thanks!

org-export-time-stamp-file: nil works as I need.

The source files *.org:

http://github.com/osiris/osiux-blog

The HTML files with images:

https://github.com/osiris/osiris.github.com

The main site:

http://osiux.com

The git mirror:

http://git.osiux.com

::

  Osiris Alejandro Gomez (OSiUX) os...@osiux.com.ar
  DC44 95D2 0D5D D544 FC1A F00F B308 A671 9237 D36C
  http://www.osiux.com.ar http://www.altermundi.net


signature.asc
Description: Digital signature


Re: [O] Bug: Babel Haskell mode [8.0.3 (8.0.3-30-g56b864-elpa @ /Users/ix/.emacs.d/elpa/org-20130610/)]

2013-06-11 Thread Simon Beaumont
Well that's really odd: I modded the paths in init.el and did the following:

emacs -Q -l init.el foo.org

When I eval'ed the code block in foo.org (twice) I still get message: Code 
block returned no value
I've attached the inferior haskell buffer and all relevant files.


init.el
Description: Binary data


foo.org
Description: Binary data
GHClet fac n = product [1..n]
[(x,fac x) | x - [0..11]]
org-babel-haskell-eoe
i, version 7.6.3: http://www.haskell.org/ghc/  :? for help
Loading package ghc-prim ... linking ... done.
Loading package integer-gmp ... linking ... done.
Loading package base ... linking ... done.
 [(0,1),(1,1),(2,2),(3,6),(4,24),(5,120),(6,720),(7,5040),(8,40320),(9,362880),(10,3628800),(11,39916800)]
 org-babel-haskell-eoe
 let fac n = product [1..n]
[(x,fac x) | x - [0..11]]
org-babel-haskell-eoe
 [(0,1),(1,1),(2,2),(3,6),(4,24),(5,120),(6,720),(7,5040),(8,40320),(9,362880),(10,3628800),(11,39916800)]
 org-babel-haskell-eoe
 
--
Looks like we are on the same versions of emacs and ghc:

ix@psi(0) [re](4843) emacs --version
GNU Emacs 24.3.1
Copyright (C) 2013 Free Software Foundation, Inc.
GNU Emacs comes with ABSOLUTELY NO WARRANTY.
You may redistribute copies of Emacs
under the terms of the GNU General Public License.
For more information about these matters, see the file named COPYING.

ix@psi(0) [re](4844) ghc --version
The Glorious Glasgow Haskell Compilation System, version 7.6.3

Org-mode version 8.0.3 (8.0.3-30-g56b864-elpa @ 
/Users/ix/.emacs.d/elpa/org-20130610/)


As far as I can tell the raw data from inferior-haskell mode is returned but 
the parsing returns null…

the raw value from:
(raw (org-babel-comint-with-output
  (session org-babel-haskell-eoe t full-body)
(insert (org-babel-trim full-body))
(comint-send-input nil t)
(insert org-babel-haskell-eoe)
(comint-send-input nil t)))
___
 ( 
 [(0,1),(1,1),(2,2),(3,6),(4,24),(5,120),(6,720),(7,5040),(8,40320),(9,362880),(10,3628800),(11,39916800)]
   
 \org-babel-haskell-eoe\ 

 )
-
 (results (mapcar
   #'org-babel-haskell-read-string
   (cdr (member org-babel-haskell-eoe
(reverse (mapcar #'org-babel-trim raw)))

but results is nil

__
I might be worth noting I am running on OS X not Linux but the raw data looks 
reasonable to me…

Simon Beaumont

On 10 Jun 2013, at 23:53, Eric Schulte schulte.e...@gmail.com wrote:

 Simon Beaumont si...@datalligator.com writes:
 
 Whenever I try and evaluate the Haskell code block I get:
 Code block returned no value.
 
 #+begin_src haskell :results value
  let fac n = product [1..n]
  [(x,fac x) | x - [0..11]]
 #+end_src
 
 #+results:
 
 
 I can't reproduce this problem.  With a minimal emacs config started
 with -Q, and loading the attached init.el file (you'll have to update
 the paths to work with your system).
 
 init.el
 I'm able to execute the following Org-mode file returning a table of
 results as expected (although I have to execute it twice, presumably to
 clear out some cruft at the beginning of the haskell session).
 
 #+begin_src haskell
  let fac n = product [1..n]
  [(x,fac x) | x - [0..11]]
 #+end_src
 
 I'm using
 
$ emacs --version
GNU Emacs 24.3.1
Copyright (C) 2013 Free Software Foundation, Inc.
GNU Emacs comes with ABSOLUTELY NO WARRANTY.
You may redistribute copies of Emacs
under the terms of the GNU General Public License.
For more information about these matters, see the file named COPYING.
 
$ ghc --version
The Glorious Glasgow Haskell Compilation System, version 7.6.3
 
Org-mode version 8.0.3 (release_8.0.3-215-g8e1e6f @ 
 /home/eschulte/src/org-mode/lisp/)
 
 -- 
 Eric Schulte
 http://cs.unm.edu/~eschulte



Re: [O] bug in new exporter

2013-06-11 Thread Nick Dokos
Nicolas Goaziou n.goaz...@gmail.com writes:

 Nick Dokos ndo...@gmail.com writes:

 Nick Dokos ndo...@gmail.com writes:

 Just a heads-up: As part of testing this, I stumbled on an unrelated
 current-working-directory problem, where on exporting to pdf, the
 pdflatex of the produced tex file fails to find an image file specified
 with a relative pathname (it works fine with an absolute path name). The
 tex file looks OK and I can process it from the command line. I'll try
 to pin this down more precisely, but do I understand correctly that the
 processing of the tex file should take place with the current working
 directory set to the directory of the org file?


 The problem was that I had customized my org-latex-pdf-process to the
 texi2dvi recommended value:

  texi2dvi -p -b -c -V %f

 The -c (equivalently: --clean or --build=clean) breaks relative paths
 because texi2dvi executes in a different directory. The *Org PDF LaTeX
 Output* buffer shows

   /usr/bin/texi2dvi: cd /home/nick/src/org/latex/foo.t2d/pdf/build

 whereas the org file was in /home/nick/src/org/latex.

 If you use texi2dvi, beware of -c (and also --tidy I presume).

 So nothing to do with org, but maybe the customization option should not
 include the -c.

 I also use texi2dvi, but I don't have any compilation problem with
 images, even with a relative path.

 Would you mind providing an ECM for that?


Please find an org file and the corresponding tex file attached. The
directory structure is as follows:

~/src/org--images--foo.png
 |
 |--latex--example.{org,tex}
 |
 |--example.t2d/pdf/build

Just executing

--8---cut here---start-8---
 texi2dvi -p -b -c -V example.tex
--8---cut here---end---8---

from the command line produces the error:

,
| /usr/bin/texi2dvi: cd /home/nick/src/org/latex/example.t2d/pdf/build
| ...
| LaTeX Warning: File `../images/foo.png' not found on input line 37.
| 
| 
| /home/nick/src/org/latex/./example.tex:37: Package pdftex.def Error: File
|  `../images/foo.png' not found.
| 
| See the pdftex.def package documentation for explanation.
| Type  H return  for immediate help.
|  ...  
|   
| l.37 ...ludegraphics[scale=1.5]{../images/foo.png}
| ...
`

Note the top line in the excerpt above. Taking out the -c gets rid of
the error (at the price of leaving all the toc/aux/log/etc files around
of course). --tidy exhibits the same symptom.

Org-mode version 8.0.3 (release_8.0.3-197-g221768 @
/home/nick/elisp/org-mode/lisp/)

#+OPTIONS: timestamp:nil

* foo

#+caption: foo
#+attr_latex:  :placement [htb!] :options scale=1.5  :width 
[[file:../images/foo.png]]

\documentclass[11pt]{article}
\usepackage[utf8]{inputenc}
\usepackage[T1]{fontenc}
\usepackage{fixltx2e}
\usepackage{graphicx}
\usepackage{longtable}
\usepackage{float}
\usepackage{wrapfig}
\usepackage{soul}
\usepackage{textcomp}
\usepackage{marvosym}
\usepackage[nointegrals]{wasysym}
\usepackage{latexsym}
\usepackage{amssymb}
\usepackage{amstext}
\usepackage{hyperref}
\tolerance=1000
\usepackage{minted}
\author{Nick Dokos}
\date{\today}
\title{example}
\hypersetup{
  pdfkeywords={},
  pdfsubject={},
  pdfcreator={Emacs 24.3.50.1 (Org mode 8.0.3)}}
\begin{document}

\maketitle
\tableofcontents


\section{foo}
\label{sec-1}

\begin{figure}[htb!]
\centering
\includegraphics[scale=1.5]{../images/foo.png}
\caption{foo}
\end{figure}
% Emacs 24.3.50.1 (Org mode 8.0.3)
\end{document} 
-- 
Nick


Re: [O] BUG - Problem in tangle-mode

2013-06-11 Thread Eric Schulte
Rainer M Krug rai...@krugs.de writes:

 Eric Schulte schulte.e...@gmail.com writes:


 I've added a :tangle-mode header argument which may be used to control
 the permissions of tangled files.  See the manual for instructions on
 it's usage.


 Thanks a lot. I will try it out today or tomorrow.

 I did, and there is a problem with tangling multiple blocks into a
 single file:


 Oh, stupid of me.  Thanks for sending this alert, I've just pushed up a
 change which should fix this problem.  We now wait to set the file modes
 until after all blocks are tangled and after the post-tangle-hook has
 been run.

 Thanks,

 Hi

 Unfortunately, it is now worse, as even without the tangle-mode header,
 I can't tangle two blocks - the second block overwrites the before
 tangled blocks. It tells me that two blocks were tangled, but only the
 last one is in the tangled file.

 I will for revert for now to the version from yesterday.

 Cheers,


Just pushed up a fix.  Cheers,

-- 
Eric Schulte
http://cs.unm.edu/~eschulte



Re: [O] link abbreviation with multiple params, e. g. for geo locations

2013-06-11 Thread Eric Schulte
Michael Brand michael.ch.br...@gmail.com writes:

 Hi Eric

 On Sun, Jun 9, 2013 at 9:18 PM, Eric Schulte schulte.e...@gmail.com wrote:
 Export buffers are sometimes modified or narrowed during the export
 process, so I wouldn't depend too much on the absolute values of markers
 generated during export.  As long as the heading in which the marker
 lives seems to be correct I'd count it as a success.

 Ok.

 Out of curiosity I also tried to assign a Lisp marker with :var

 #+HEADER: :var marker-var=(identity org-babel-current-src-block-location)

 which leads to

 executing Emacs-Lisp code block (func)...
 (marker-var (quote #marker at 458 in marker_offset.org))
 eval: Invalid read syntax: #


You'll get this if you do the following.

  ;; -*- emacs-lisp -*-
  (read-from-string (format %s (point-marker)))

This is because unlike most lisp objects, point markers can not be read
in the same syntax they print as.  Babel only supports passing strings,
numbers, and lists of strings and numbers as variables between code
blocks.  If you convert the point-marker to a point (integer) then it
will flow between blocks.


 Is such a Lisp marker supposed to work across a :var assignment? For
 me it does not matter because either the variable
 org-babel-current-src-block-location is better evaluated within the
 source block or in the header I do not expect the value to be of much
 use for source blocks other than Lisp. I just let you know in case you
 wanted the assignment to work with other #-constructs or there was a
 connection with the recent changes that temporarily required :shebang
 quoting.

 Michael

-- 
Eric Schulte
http://cs.unm.edu/~eschulte



Re: [O] ox-koma-letter support for \cc and \encl?

2013-06-11 Thread Vikas Rawal

 
 Yes. Add two headlines to your letter, one tagged with :CC: and one with
 :ENCL:. The content below these headlines will be converted to the
 relevant LaTeX code. This also works with :PS:. However, you need a
 fairly recent version of ox-koma-letter.

Thanks. Works perfect. Is it documented anywhere?

Best,

Vikas



Re: [O] BUG - Problem in tangle-mode

2013-06-11 Thread Rainer M Krug
On Tuesday, June 11, 2013, Eric Schulte wrote:

 Rainer M Krug rai...@krugs.de javascript:; writes:

  Eric Schulte schulte.e...@gmail.com javascript:; writes:
 
 
  I've added a :tangle-mode header argument which may be used to
 control
  the permissions of tangled files.  See the manual for instructions on
  it's usage.
 
 
  Thanks a lot. I will try it out today or tomorrow.
 
  I did, and there is a problem with tangling multiple blocks into a
  single file:
 
 
  Oh, stupid of me.  Thanks for sending this alert, I've just pushed up a
  change which should fix this problem.  We now wait to set the file modes
  until after all blocks are tangled and after the post-tangle-hook has
  been run.
 
  Thanks,
 
  Hi
 
  Unfortunately, it is now worse, as even without the tangle-mode header,
  I can't tangle two blocks - the second block overwrites the before
  tangled blocks. It tells me that two blocks were tangled, but only the
  last one is in the tangled file.
 
  I will for revert for now to the version from yesterday.
 
  Cheers,
 

 Just pushed up a fix.  Cheers,


Thanks. Will try it out tomorrow,

Cheers,

Rainer


 --
 Eric Schulte
 http://cs.unm.edu/~eschulte



-- 
Rainer M. Krug, PhD (Conservation Ecology, SUN), MSc (Conservation Biology,
UCT), Dipl. Phys. (Germany)

Centre of Excellence for Invasion Biology
Stellenbosch University
South Africa

Tel :   +33 - (0)9 53 10 27 44
Cell:   +33 - (0)6 85 62 59 98
Fax (F):   +33 - (0)9 58 10 27 44

Fax (D):+49 - (0)3 21 21 25 22 44

email:  rai...@krugs.de

Skype:  RMkrug


Re: [O] [PATCH] org-contacts: Provide ordering when using cycle completion

2013-06-11 Thread Daimrod
Øyvind Stegard oyvi...@ifi.uio.no writes:

 Hello list,

Hello,

Merged into master, thanks for patch!

 I have recently switched to using org-contacts, after several years of
 BBDB usage. When completing contacts in message-mode, I prefer cycling
 the completion alternatives, for instance when a single contact has
 multiple email addresses. So I set `completion-cycle-threshold' to some
 value other than nil.

 However, the cycle ordering was not consistent with the order in which
 email addresses appeared in the contact (actually, cycle order was
 shortest candidate first, which I understand is a default). So the
 preferred email address (or the first one defined in :EMAIL: property
 of contact node) was typically not always chosen as first completion
 suggestion in the cycle.

 I attach a patch here (against current org-mode git) which also provides
 the display sort function for cycle completions in metadata. That seems
 to resolve the problem for me.


 Regards,

 Øyvind Stegard
 -- 
  Øyvind Stegard
   http://stegard.net/


 From 64623274f0a040c452df43b2a3f7b23b0af8fd57 Mon Sep 17 00:00:00 2001
 From: =?UTF-8?q?=C3=98yvind=20Stegard?= oyvind.steg...@ifi.uio.no
 Date: Mon, 10 Jun 2013 11:08:56 +0200
 Subject: [PATCH] org-contacts: Provide ordering when using cycle completion

 * contrib/lisp/org-contacts.el (org-contacts-metadata-prefix):
 Provide same function for cycle ordering as is used for display ordering
 in completion metadata.

 When using cycle completion style for contacts, by setting
 `completion-cycle-threshold' to some value, the ordering was not consistent
 with order of email addresses in contact definition, nor the order
 which was used for regular display completion. Fix that by also
 supplying sort function for cycle completion in metadata.
 ---
  contrib/lisp/org-contacts.el | 3 ++-
  1 file changed, 2 insertions(+), 1 deletion(-)

 diff --git a/contrib/lisp/org-contacts.el b/contrib/lisp/org-contacts.el
 index 5d63fcc..71f7bf4 100644
 --- a/contrib/lisp/org-contacts.el
 +++ b/contrib/lisp/org-contacts.el
 @@ -452,7 +452,8 @@ prefixes rather than just the beginning of the string.
  
  (defun org-contacts-metadata-prefix (string collection predicate)
'(metadata .
 -  ((display-sort-function . org-contacts-display-sort-function
 +  ((cycle-sort-function . org-contacts-display-sort-function)
 +   (display-sort-function . org-contacts-display-sort-function
  
  (defun org-contacts-complete-group (start end string)
Complete text at START from a group.

-- 
Daimrod/Greg


signature.asc
Description: PGP signature


[O] [RFC] BibELTeX: native bibtex support in org-mode

2013-06-11 Thread Rüdiger Sonderfeld
Hello,

I've started writing BibELTeX as an alternative to =ox-bibtex.el=. 

https://github.com/ruediger/bibeltex

Instead of calling =bibtex2html= it uses the functionality from =org-
bibtex.el= to parse the BibTeX file and generates org-mode format for it. This 
has the advantage that it works with any output format (latex, html, odt, 
ascii, ...) and that it does not require external tools.

BibELTeX is currently in a very early stage of development.  The biggest 
design issue is the style format.  Currently I use a =format-spec= like format 
which is not very good to work with (See =bibeltex-style-default=).

Please feel free to criticise, comment, and open pull requests!

Regards
Rüdiger




[O] face for inline-tasks

2013-06-11 Thread Andreas Leha
Hi all,

how can I achieve, that the whole inline-task uses a font face
(esp. with background)?

I customized the face org-inlinetask, but that only fontifies the last
stars and the 'END'.  I would like to color the whole line plus all the
contents.  I have similar settings for my code blocks and find it very
convenient.
(see http://orgmode.org/worg/images/color-themes/color-theme-leuven.png
for an example of what I mean)

Is that possible for inline-tasks, as well?

Best,
Andreas




Re: [O] export to odt

2013-06-11 Thread Manfred Lotz
On Tue, 11 Jun 2013 11:33:56 +0100
Eric S Fraga e.fr...@ucl.ac.uk wrote:

 Manfred Lotz manfred.l...@arcor.de writes:
 
 [...]
 
  The following worked fine: I loaded the exported odt document,
  changed the Heading 1 style to do a page break before the heading
  and saved the template as my.ott (I copied it into the ~/org
  directory).
 
 Thanks.  Very helpful.
 
 I have two different questions about exporting to ODT, one related to
 style and other not:
 
 1. Description lists are indented somehow, both the item and the
  description.  I would like to change the indentation but the
  LibreOffice sytle dialogue doesn't show any indentation.  I
 cannot find where the indentation is specified.
 

Hm, not quite sure about this as I am no expert regarding Libreoffice.
I will have a look if I find anything about this.

 2. The title and author fields in the exported document are protected
 in some way and I cannot figure out how to enable editing on them.  I
  can change the style for these just fine but I cannot change the
  text.
 

You easily can setup both title and author in your org document like
this:

#+TITLE: My Important Documentation
#+AUTHOR: Manfred Lotz

Is this what you mean?


-- 
Manfred



Re: [O] ox-koma-letter support for \cc and \encl?

2013-06-11 Thread Rasmus
Vikas Rawal vikasli...@agrarianresearch.org writes:

 
 Yes. Add two headlines to your letter, one tagged with :CC: and one with
 :ENCL:. The content below these headlines will be converted to the
 relevant LaTeX code. This also works with :PS:. However, you need a
 fairly recent version of ox-koma-letter.

 Thanks. Works perfect. Is it documented anywhere?

In the changelogs mostly.  I have some documentation locally as well
that hasn't been applied.  Here's an unpolished quote:

;; Headlines are in general ignored.  However, headlines with special
;; tags can be used for specified contents like postscript (ps), carbon
;; copy (cc), encloses (encl) and code to be inserted after
;; \end{letter} (after_letter).

–Rasmus

-- 
Hvor meget poesi tror De kommer ud af et glas isvand?




Re: [O] ox-koma-letter support for \cc and \encl?

2013-06-11 Thread Viktor Rosenfeld
Hi Vikas,

Vikas Rawal wrote:

 
  
  Yes. Add two headlines to your letter, one tagged with :CC: and one with
  :ENCL:. The content below these headlines will be converted to the
  relevant LaTeX code. This also works with :PS:. However, you need a
  fairly recent version of ox-koma-letter.
 
 Thanks. Works perfect. Is it documented anywhere?

I'll document it in the tutorial once Org-mode 8.1 is released. Right
now this feature is only available in master.

Cheers,
Viktor

 
 Best,
 
 Vikas
 



Re: [O] ox-koma-letter support for \cc and \encl?

2013-06-11 Thread Viktor Rosenfeld
Hi Rasmus,

I didn't have time to look at your code on the weekend, but I had to
write a letter with ENCL and it worked perfectly. I'm liking this setup
more and more. I don't know if you went ahead and implemented the
:with-legacy option, but I think it should default to `nil', so the
stuff in the headlines takes precedence.

Cheers,
Viktor

Rasmus wrote:

 Vikas Rawal vikasli...@agrarianresearch.org writes:
 
  
  Yes. Add two headlines to your letter, one tagged with :CC: and one with
  :ENCL:. The content below these headlines will be converted to the
  relevant LaTeX code. This also works with :PS:. However, you need a
  fairly recent version of ox-koma-letter.
 
  Thanks. Works perfect. Is it documented anywhere?
 
 In the changelogs mostly.  I have some documentation locally as well
 that hasn't been applied.  Here's an unpolished quote:
 
 ;; Headlines are in general ignored.  However, headlines with special
 ;; tags can be used for specified contents like postscript (ps), carbon
 ;; copy (cc), encloses (encl) and code to be inserted after
 ;; \end{letter} (after_letter).
 
 –Rasmus
 
 -- 
 Hvor meget poesi tror De kommer ud af et glas isvand?
 
 



Re: [O] [patch][ox-koma-letter] Support for to and from headings

2013-06-11 Thread Rasmus
Rasmus ras...@gmx.us writes:

 Rasmus ras...@gmx.us writes:

 Hi,

 Some more patches that should work against the master branch.

 Patch 1: bug fixes.  Most notably use symbols some places rather than
 strings.

 Patch 2 adds support for TO and FROM headings.  If you've got time for
 testing I would appreciate feedback.  It's explained in the top of the
 patch.

 Patch 1 and 2 are updated.  Patch three adds support for an
 `org-koma-letter-default-class' and a plug-in function to make it
 easier to use letters.  They should apply against master.

Updated again and hopefully better changelog etc. . .

–Rasmus

--
This is the kind of tedious nonsense up with which I will not put
From b3d3d781a32990e3b7e5ca5f2812a106a458814c Mon Sep 17 00:00:00 2001
From: rasmus.pank rasmus.p...@gmail.com
Date: Mon, 27 May 2013 17:29:14 +0200
Subject: [PATCH 1/4] Bug fixes for ox-koma-letter.el

* ox-koma-letter.el: updated documentation and improved defcustoms.
(org-koma-letter-special-tags-after-letter)
(org-koma-letter-special-tags-after-closing): now symbol.
(org-koma-letter--get-custom): falls back to value
(org-koma-letter--prepare-special-contents-as-macro): let
newlines be handled outside of the function
(org-koma-letter--remove-offending-new-lines): function to add
new lines.
(org-koma-letter-headline): updated to work with symbols and
made more robust.
(org-koma-letter-export-to-latex): reset
=`org-koma-letter-special-contents'= to nil
---
 contrib/lisp/ox-koma-letter.el | 118 -
 1 file changed, 81 insertions(+), 37 deletions(-)

diff --git a/contrib/lisp/ox-koma-letter.el b/contrib/lisp/ox-koma-letter.el
index 4af0ba7..8f24d83 100644
--- a/contrib/lisp/ox-koma-letter.el
+++ b/contrib/lisp/ox-koma-letter.el
@@ -33,12 +33,43 @@
 ;;
 ;; On top of buffer keywords supported by `latex' back-end (see
 ;; `org-latex-options-alist'), this back-end introduces the following
-;; keywords: CLOSING (see `org-koma-letter-closing'), FROM_ADDRESS
-;; (see `org-koma-letter-from-address'), LCO (see
-;; `org-koma-letter-class-option-file'), OPENING (see
-;; `org-koma-letter-opening'), PHONE_NUMBER (see
-;; `org-koma-letter-phone-number'), SIGNATURE (see
-;; `org-koma-letter-signature') and TO_ADDRESS.
+;; keywords:
+;;   - CLOSING (see `org-koma-letter-closing'),
+;;   - FROM_ADDRESS (see `org-koma-letter-from-address'),
+;;   - LCO (see `org-koma-letter-class-option-file'),
+;;   - OPENING (see `org-koma-letter-opening'),
+;;   - PHONE_NUMBER (see `org-koma-letter-phone-number'),
+;;   - SIGNATURE (see `org-koma-letter-signature')
+;;   - PLACE (see `org-koma-letter-place')
+;;   - and TO_ADDRESS.
+;;
+;; A number of OPTIONS settings can be set to change which contents is
+;; exported.
+;;   - backaddress (see `org-koma-letter-use-backaddress')
+;;   - foldmarks (see `org-koma-letter-use-foldmarks')
+;;   - phone (see `org-koma-letter-use-phone')
+;;   - email (see `org-koma-letter-use-email')
+;;   - place (see `org-koma-letter-use-place')
+;;   - subject, a list of format options
+;; (see `org-koma-letter-subject-format')
+;;   - after-closing-order, a list of the ordering of headings with
+;; special tags after closing (see
+;; `org-koma-letter-special-tags-after-closing') -
+;; after-letter-order, as above, but after the end of the letter
+;; (see `org-koma-letter-special-tags-after-letter').
+;;
+;; The following variables works differently from the main LaTeX class
+;;   - AUTHOR: default to user-full-name but may be disabled.  (see org-koma-letter-author),
+;;   - EMAIL: same as AUTHOR, (see org-koma-letter-email),
+;;
+;; Headlines are in general ignored.  However, headlines with special
+;; tags can be used for specified contents like postscript (ps),
+;; carbon copy (cc), enclosures (encl) and code to be inserted after
+;; \end{letter} (after_letter).  Specials tags are defined in
+;; `org-koma-letter-special-tags-after-closing' and
+;; `org-koma-letter-special-tags-after-letter'.  Currently members of
+;; `org-koma-letter-special-tags-after-closing' used as macros and the
+;; content of the headline is the argument.
 ;;
 ;; You will need to add an appropriate association in
 ;; `org-latex-classes' in order to use the KOMA Scrlttr2 class.  For
@@ -93,7 +124,7 @@ string.
   :type '(radio (function-item user-full-name)
 		(string)
 		(function)
-		(const nil)))
+		(const :tag Do not export author nil)))
 
 (defcustom org-koma-letter-email 'org-koma-letter-email
   The sender's email address.
@@ -105,7 +136,7 @@ function may be given.  Functions must return a string.
   :type '(radio (function-item org-koma-letter-email)
 		(string)
 		(function)
-		(const nil)))
+		(const :tag Do not export email nil)))
 
 (defcustom org-koma-letter-from-address nil
   Sender's address, as a string.
@@ -153,17 +184,19 @@ writing the following values are allowed:
 
 Please refer to the KOMA-script manual (Table 4.16. in the
 English manual of 2012-07-22)
-  :type '(set   (const  

Re: [O] ox-koma-letter support for \cc and \encl?

2013-06-11 Thread Rasmus
Viktor Rosenfeld listuse...@gmail.com writes:

 I didn't have time to look at your code on the weekend, but I had to
 write a letter with ENCL and it worked perfectly. I'm liking this setup
 more and more. I don't know if you went ahead and implemented the
 :with-legacy option, but I think it should default to `nil', so the
 stuff in the headlines takes precedence.

The :with-legacy was too harsh a name ¹, I never wanted to call it
that.  It's implemented as (not :with-legacy), i.e. a
:prefer-special-headings or something like that.  It's in the second
patch I that I just re-posted.  Also, I updated the documentation in
the top of the file.  While my prose is not as clear as the tutorial,
it should be hopefully be understandable.

–Rasmus

-- 
May contains speling mistake




Re: [O] A simple way to search only headlines

2013-06-11 Thread Suvayu Ali
Hi Thorsten,

On Tue, Jun 11, 2013 at 04:42:28PM +0200, Thorsten Jolitz wrote:
 Suvayu Ali fatkasuvayu+li...@gmail.com writes:
 
  I wonder if semantic search can be leveraged to achieve the same.  It
  might open other possibilities: searching only links, list items, source
  blocks, ...  I think you get the point.  :-p
 
 navi-mode.el works for Org-mode buffers too, e.g. using 

I think you misunderstood somewhat what I was suggesting.

As far as I understand, navi-mode uses an interface like occur; it
presents a separate buffer with the results which you can then use to
navigate to the results.  Am I correct?

What I was suggesting (and how I understood the OPs question) was, to
restrict regular (i)search to headlines.  Consider the following example
Org buffer:


  * Top heading
  
  ** Sub-heading 1
  + List entry
  + Another entry with an enumerated list
1. Foo
2. Bar
  
  ** Another sub-heading


Now with such restriction enabled, `C-s A n o t h e r' will navigate to
the headline (just like regular isearch-forward)

  ** Another sub-heading

not the list item

  + Another entry with an enumerated list

As far as I know, functionality like this exists for traditional source
code buffers using semantic search.  I was wondering if it is possible
to leverage that mechanism to get the behaviour described above.  If it
is indeed possible, it could be hacked to work for other Org syntax
elements like links, lists, source blocks, drawers, etc.

Hopefully I didn't misunderstand your post and I was clearer expressing
myself this time.

Cheers,

-- 
Suvayu

Open source is the future. It sets us free.



Re: [O] [PATCH (v5)][ox-latex.el] Allow AUTO argument to org-latex-guess-babel-language.

2013-06-11 Thread Rasmus
Nicolas Goaziou n.goaz...@gmail.com writes:

 The patch looks good, but the feature needs to be documented. I think
 you could add a paragraph in `org-latex-classes' docstring, below the
 first reference to AUTO.

v5! Documentation added.  Let me know if more stuff needs to be
polished.

–Rasmus

-- 
May contains speling mistakeFrom 7f1cc30ccbedfa7c5689dbf8408011e64db75230 Mon Sep 17 00:00:00 2001
From: rasmus.pank rasmus.p...@gmail.com
Date: Sat, 1 Jun 2013 00:20:18 +0200
Subject: [PATCH] Allow AUTO argument to org-latex-guess-babel-language.

* ox-latex.el (org-latex-guess-babel-language): replace AUTO with
  language if AUTO is the option of the LaTeX package Babel.  *
  (org-latex-classes): updated documentation with respect
  to =`org-latex-guess-babel-language'=
---
 lisp/ox-latex.el | 31 +++
 1 file changed, 23 insertions(+), 8 deletions(-)

diff --git a/lisp/ox-latex.el b/lisp/ox-latex.el
index df3de4c..d409cf8 100644
--- a/lisp/ox-latex.el
+++ b/lisp/ox-latex.el
@@ -261,6 +261,14 @@ replaced with a coding system derived from
 `buffer-file-coding-system'.  See also the variable
 `org-latex-inputenc-alist' for a way to influence this mechanism.
 
+Likewise, if your header contains \\\usepackage[AUTO]{babel}\,
+AUTO will be replaced with the export language as specified by
+the LANGUAGE keyword or `org-export-default-language'.  Note that
+constructions such as
+\\\usepackage[french, AUTO, english]{babel}\
+are permitted.  For more information refer to
+`org-latex-guess-babel-language'.
+
 The sectioning structure
 
 
@@ -910,6 +918,10 @@ Insertion of guessed language only happens when Babel package has
 explicitly been loaded.  Then it is added to the rest of
 package's options.
 
+The argument to Babel may be \AUTO\ which is then replaced with
+the language of the document or `org-export-default-language'
+unless language in question is already loaded.
+
 Return the new header.
   (let ((language-code (plist-get info :language)))
 ;; If no language is set or Babel package is not loaded, return
@@ -918,16 +930,19 @@ Return the new header.
 	(not (string-match usepackage\\[\\(.*\\)\\]{babel} header)))
 	header
   (let ((options (save-match-data
-		   (org-split-string (match-string 1 header) ,)))
+		   (org-split-string (match-string 1 header) ,[ \t]*)))
 	(language (cdr (assoc language-code
   org-latex-babel-language-alist
-	;; If LANGUAGE is already loaded, return header.  Otherwise,
-	;; append LANGUAGE to other options.
-	(if (member language options) header
-	  (replace-match (mapconcat 'identity
-(append options (list language))
-,)
-			 nil nil header 1))
+	;; If LANGUAGE is already loaded, return header without AUTO.
+	;; Otherwise, replace AUTO with language or append language if
+	;; AUTO is not present.
+	(replace-match
+	 (mapconcat (lambda (option) (if (equal AUTO option) language option))
+		(cond ((member language options) (delete AUTO options))
+			  ((member AUTO options) options)
+			  (t (append options (list language
+		, )
+	 t nil header 1)
 
 (defun org-latex--find-verb-separator (s)
   Return a character not used in string S.
-- 
1.8.3



[O] List of Figures not being generated in 8.0.3?

2013-06-11 Thread Luke Crook
I just noticed that the List of Figures is not being generated in 8.0.3.

I have a figure with;

#+LATEX: \listoffigures

#+ATTR_LaTeX: width=5.5cm
#+CAPTION: A Caption Here
#+LABEL: fig:test-figure-1
#+begin_src plantuml :file test-figure-1.png :cmdline -Tpng
plantuml stuff here
#+end_src

I have verified that the png is being generated in 8.0.3.  However the
figure is not being included in the List of Figures.

References to the figure \ref{fig:test-figure-1} will render as ?? in the
Latex output.  There references render as \ref{fig:test-figure-1} in the
HTML output.

Works correctly in org-more 7.8.11

Can anyone help?


Re: [O] [RFC] BibELTeX: native bibtex support in org-mode

2013-06-11 Thread Rasmus
Rüdiger Sonderfeld ruedi...@c-plusplus.de writes:

 I've started writing BibELTeX as an alternative to =ox-bibtex.el=. 

 https://github.com/ruediger/bibeltex

Would you consider providing a test file showing off its features?

 Instead of calling =bibtex2html= it uses the functionality from =org-
 bibtex.el= to parse the BibTeX file and generates org-mode format for it. 
 This 
 has the advantage that it works with any output format (latex, html, odt, 
 ascii, ...) and that it does not require external tools.

I'm skeptical but probably it is 'cause I've misunderstood something!
Someone put a lot of thought into writing e.g. biblatex or
odt-bibliographies.  Surely(?) we would want to leverage upon those
and only have org-support insofar as serving some backend-specific
parser enough information to do its work?

–Rasmus

-- 
May the Force be with you




[O] [suggest] We should import latex template system

2013-06-11 Thread Feng Shu

Hi:

org-mode odt exporter are using 'org-odt-styles-file, which are odt
templetes, I think latex exporter should do like this. for example:

   
org-latex-styles-file  or  org-latex-templete-file


we can include many different language's templates into org, and no need
touch the ox-latex.el and the user can write theirs template easily,



we can use locale to determine which template will be used



converting latex fragements can use templates too, like:


org-latex-fragment-templete-file



-- 



Re: [O] A simple way to search only headlines

2013-06-11 Thread Thorsten Jolitz
Suvayu Ali fatkasuvayu+li...@gmail.com writes:

Hi Suvayu,

 On Tue, Jun 11, 2013 at 04:42:28PM +0200, Thorsten Jolitz wrote:
 Suvayu Ali fatkasuvayu+li...@gmail.com writes:
 
  I wonder if semantic search can be leveraged to achieve the same.  It
  might open other possibilities: searching only links, list items, source
  blocks, ...  I think you get the point.  :-p
 
 navi-mode.el works for Org-mode buffers too, e.g. using 

 I think you misunderstood somewhat what I was suggesting.

 As far as I understand, navi-mode uses an interface like occur; it
 presents a separate buffer with the results which you can then use to
 navigate to the results.  Am I correct?

yes, it works on top of occur-mode in a separate buffer, but *Navi*
buffer are permanent, and there can exist many of them at the same time. 

 What I was suggesting (and how I understood the OPs question) was, to
 restrict regular (i)search to headlines.  
[...]
 As far as I know, functionality like this exists for traditional source
 code buffers using semantic search.  I was wondering if it is possible
 to leverage that mechanism to get the behaviour described above.  If it
 is indeed possible, it could be hacked to work for other Org syntax
 elements like links, lists, source blocks, drawers, etc.

 Hopefully I didn't misunderstand your post and I was clearer expressing
 myself this time.

I think I more or less understood what the thread was about, but thanks
anyway for the clarification. Of course navi-mode does not offer
semantic search within an Org-mode buffer. But for practical purposes
it might be worth mentioning that typing one digit between 1 and 8 and
then C-s or C-r in the *Navi* buffer lets you already search easily only
in the headlines of an Org file. And many other views on a file are
possible, that can then be searched by standard commands. With keyboard
macros and switching between original buffer and *Navi* buffer (and
using org-mark-element e.g.), a lot can be achieved without the need of
writing any elisp code.

-- 
Cheers,
Thorsten




Re: [O] List of Figures not being generated in 8.0.3?

2013-06-11 Thread Rasmus


Hi Luke!

 I just noticed that the List of Figures is not being generated in 8.0.3.

 I have a figure with;

 #+LATEX: \listoffigures

 #+ATTR_LaTeX: width=5.5cm
 #+CAPTION: A Caption Here
 #+LABEL: fig:test-figure-1
 #+begin_src plantuml :file test-figure-1.png :cmdline -Tpng
 plantuml stuff here
 #+end_src
 I have verified that the png is being generated in 8.0.3.  However the
 figure is not being included in the List of Figures.

 References to the figure \ref{fig:test-figure-1} will render as ?? in the
 Latex output.  There references render as \ref{fig:test-figure-1} in the
 HTML output.

 Works correctly in org-more 7.8.11

It seems you're using v8.0.3. . .

 Can anyone help?

Surely the manual: http://orgmode.org/org.html.

Your example would be something like 

#+OPTIONS: toc:nil
#+TOC: figures ## -- not implemented currently
#+LATEX: \listoffigures


Correlation between the manual and proficiency is displayed in figure
[[fig:test-figure-1]]

#+NAME: gen-correlation
#+begin_src plantuml :file test-figure-1.png :cmdline -Tpng
  code which returns test-figure-1.png 
#+end_src


#+ATTR_LaTeX: :width 5.5cm
#+CAPTION: A Caption Here
#+NAME: fig:test-figure-1
#+RESULTS: gen-correlation
[[file:test-figure-1.png]]


-- 
m-mm-mmm- bacon!




[O] Agenda printing: org-agenda-write doesn't use ps-paper-type

2013-06-11 Thread Myles English
Hello,

Trying to print an agenda to pdf always results in the paper size being
US letter even though ps-paper-type is set to a4.

This is how I try to print it:

(org-agenda-write /home/myles/tmp/agenda.pdf nil nil *Org Agenda(a)*)

and setting this doesn't fix it either:

(eval-after-load ps-print
  '(setq ps-paper-type 'a4))

Is there something else I need to customise?

Thanks,

Myles



Re: [O] export to odt

2013-06-11 Thread Manfred Lotz
Hi Eric,

On Tue, 11 Jun 2013 11:33:56 +0100
Eric S Fraga e.fr...@ucl.ac.uk wrote:

 Manfred Lotz manfred.l...@arcor.de writes:
 
 [...]
 
  The following worked fine: I loaded the exported odt document,
  changed the Heading 1 style to do a page break before the heading
  and saved the template as my.ott (I copied it into the ~/org
  directory).
 
 Thanks.  Very helpful.
 
 I have two different questions about exporting to ODT, one related to
 style and other not:
 
 1. Description lists are indented somehow, both the item and the
  description.  I would like to change the indentation but the
  LibreOffice sytle dialogue doesn't show any indentation.  I
 cannot find where the indentation is specified.
 

I found the following. You open the Modify Dialog for style
OrgDescriptionList. Here you choose tab Position. Then you can modify
indentation for level 1 and 2.

Example:
org mode:

  - dog :: is an animal 

In odt document

   dog 
  is an animal

Then dog is level 1 and 'is an animal' is level 2.


Then as previously described the style could be saved in an .ott file
and be specified in the org file itself.


Hope this helps.


-- 
Manfred